(use-translation _acc_ "alterator-acc")
;window definitions
caption "ALT Linux Control Center"
;backgroundpixmap "bg-1024x768.png"

;load frame
(include-as-is "/dialog/frame")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;work with steps ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(define (fetch-acc-hooks)
  (map (lambda (x) (list-ref x 4)) (mapper-view-all '/acc-hook)))

(define (get-acc-steps)
  (define (get-option st name default)
    (let loop ((cmd (mapper-view st)))
      (or (cond-cdr (command-arg-ref cmd name))
	  (and (eq? (list-ref cmd 2) 'view)
	       (loop (mapper-view (list-ref cmd 4))))
	  default)))
  (sort
    (map
      (lambda (step)
	(list (get-option step 'description "unknown")
	      (get-option step 'acc-icon "/usr/share/design-current/icons/mini/altlinux.png")
	      step))
	(fetch-acc-hooks))
    (lambda (x y)
      (string<? (car x) (car y)))))

(define *acc-steps* (get-acc-steps)) ;full step-list

;current step number in list
(define *acc-current-step-number* -1)

(define (acc-get-step num) (caddr (list-ref *acc-steps*  num)))

;;;;;;;;;;;;;;;; step changing ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (acc-remark-global url)
	  (dlg-frame-global-set!
	    (find (lambda (x) (eq? (caddr x) (sure-symbol url)))
		  *acc-steps*)))

; ;update help content, button texts and title-line
(on-goto
  (set! *acc-current-step-number* (step-list current))
  (acc-remark-global url)
  (next-button text (dlg-frame-next-button-text))
  (prev-button text (dlg-frame-prev-button-text)))

(on-before-goto
  (page 'delete-event on-next on-prev on-acc-leave on-apply))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; steps list ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define *acc-under-selection* #f)

(define (acc-protected func)
  (and (not *acc-under-selection*)
       (begin
	 (set! *acc-under-selection* #t)
	 (func)
	 (set! *acc-under-selection* #f))))

(define (acc-process-change status)
  (case status
    ((locked) (run-dialog `(/information message ,(_acc_ "Module is locked")))
	      (acc-process-change 'stay-on))
    ((stay-on) (step-list current *acc-current-step-number*) #t)
    ((need-confirm) (acc-process-change (run-dialog '(/acc-confirm))))
    ((apply-and-go) (if (page 'call on-apply)
		      (acc-process-change 'discard)
		      (acc-process-change 'stay-on)))
    (else ;discard
      (dlg-frame-goto (acc-get-step (step-list current))))))

(define (acc-step-labels)
  (map (lambda(x) (cons (car x) (cadr x))) *acc-steps*))

(define (acc-make-step-list w h)
  (id 'step-list (listbox sizepolicy '(maximum . expanding)
		  width w
		  height h
		  (items (acc-step-labels))
                  (on-select 
		    (acc-protected
		      (lambda() 
				(acc-process-change
				  (page 'call on-acc-leave))))))))

width 80
height 90

;widget description
(hbox
	width 80
	height 90
  	margin 1
	(acc-make-step-list 18 90)
  	(dlg-make-frame 80 90 '/acc-welcome))

